@@ -10,10 +10,7 @@
 #include "scheduler.h"
 #include "scheduler_p.h"
 
-#include "connection_p.h"
 #include "job_p.h"
-#include "kprotocolmanager_p.h"
-#include "sessiondata_p.h"
 #include "worker_p.h"
 #include "workerconfig.h"
 
@@ -38,11 +35,6 @@ static inline Worker *jobSWorker(SimpleJob *job)
     return SimpleJobPrivate::get(job)->m_worker;
 }
 
-static inline int jobCommand(SimpleJob *job)
-{
-    return SimpleJobPrivate::get(job)->m_command;
-}
-
 static inline void startJob(SimpleJob *job, Worker *worker)
 {
     SimpleJobPrivate::get(job)->start(worker);
@@ -73,10 +65,7 @@ public:
     QUrl m_urlOnHold;
     bool m_ignoreConfigReparse = false;
 
-    SessionData sessionData;
-
     void doJob(SimpleJob *job);
-    void setJobPriority(SimpleJob *job, int priority);
     void cancelJob(SimpleJob *job);
     void jobFinished(KIO::SimpleJob *job, KIO::Worker *worker);
     void putWorkerOnHold(KIO::SimpleJob *job, const QUrl &url);
@@ -127,14 +116,6 @@ Scheduler *scheduler()
 
 ////////////////////////////
 
-int SerialPicker::changedPrioritySerial(int oldSerial, int newPriority) const
-{
-    Q_ASSERT(newPriority >= -10 && newPriority <= 10);
-    newPriority = qBound(-10, newPriority, 10);
-    int unbiasedSerial = oldSerial % m_jobsPerPriority;
-    return unbiasedSerial + newPriority * m_jobsPerPriority;
-}
-
 WorkerManager::WorkerManager()
 {
     m_grimTimer.setSingleShot(true);
@@ -383,29 +364,6 @@ void ProtoQueue::queueJob(SimpleJob *job)
     ensureNoDuplicates(&m_queuesBySerial);
 }
 
-void ProtoQueue::changeJobPriority(SimpleJob *job, int newPrio)
-{
-    SimpleJobPrivate *jobPriv = SimpleJobPrivate::get(job);
-    QHash<QString, HostQueue>::Iterator it = m_queuesByHostname.find(jobPriv->m_url.host());
-    if (it == m_queuesByHostname.end()) {
-        return;
-    }
-    HostQueue &hq = it.value();
-    const int prevLowestSerial = hq.lowestSerial();
-    if (hq.isJobRunning(job) || !hq.removeJob(job)) {
-        return;
-    }
-    jobPriv->m_schedSerial = m_serialPicker.changedPrioritySerial(jobPriv->m_schedSerial, newPrio);
-    hq.queueJob(job);
-    const bool needReinsert = hq.lowestSerial() != prevLowestSerial;
-    // the host queue might be absent from m_queuesBySerial because the connections per host limit
-    // for that host has been reached.
-    if (needReinsert && m_queuesBySerial.remove(prevLowestSerial)) {
-        m_queuesBySerial.insert(hq.lowestSerial(), &hq);
-    }
-    ensureNoDuplicates(&m_queuesBySerial);
-}
-
 void ProtoQueue::removeJob(SimpleJob *job)
 {
     SimpleJobPrivate *jobPriv = SimpleJobPrivate::get(job);
@@ -655,7 +613,6 @@ void SchedulerPrivate::slotReparseSlaveConfiguration(const QString &proto, const
     // qDebug() << "proto=" << proto;
     KProtocolManager::reparseConfiguration();
     WorkerConfig::self()->reset();
-    sessionData.reset();
 
     QHash<QString, ProtoQueue *>::ConstIterator it = proto.isEmpty() ? m_protocols.constBegin() : m_protocols.constFind(proto);
     QHash<QString, ProtoQueue *>::ConstIterator endIt = m_protocols.constEnd();
@@ -690,16 +647,6 @@ void SchedulerPrivate::doJob(SimpleJob *job)
     proto->queueJob(job);
 }
 
-void SchedulerPrivate::setJobPriority(SimpleJob *job, int priority)
-{
-    // qDebug() << job << priority;
-    const QString protocol = SimpleJobPrivate::get(job)->m_protocol;
-    if (!protocol.isEmpty()) {
-        ProtoQueue *proto = protoQ(protocol, job->url().host());
-        proto->changeJobPriority(job, priority);
-    }
-}
-
 void SchedulerPrivate::cancelJob(SimpleJob *job)
 {
     KIO::SimpleJobPrivate *const jobPriv = SimpleJobPrivate::get(job);
@@ -765,7 +712,6 @@ MetaData SchedulerPrivate::metaDataFor(const QString &protocol, const QUrl &url)
 {
     const QString host = url.host();
     MetaData configData = WorkerConfig::self()->configData(protocol, host);
-    sessionData.configDataFor(configData, protocol, host);
 
     return configData;
 }
